import argparse, sys

def parse_args(args_n_types):
    # Create an ArgumentParser object
    parser = argparse.ArgumentParser()

    # Add arguments dynamically based on args_n_types dictionary
    for arg, arg_type in args_n_types.items():
        parser.add_argument(f'--{arg}', type=arg_type, help=f'Specify {arg}')

    # Parse the command-line arguments
    args = parser.parse_args()

    # Create a dictionary to store the parsed arguments
    parsed_args = {}

    # Check if values are not provided
    for arg in args_n_types:
        if getattr(args, arg) is None:
            parsed_args[arg] = input(f'Please enter a value for {arg}: ')
        else:
            parsed_args[arg] = getattr(args, arg)

    # Check if any value is still missing
    if any(value is None for value in parsed_args.values()):
        print('Missing required values. Exiting the program.')
        sys.exit(1)

    return parsed_args
